@@ -48,17 +48,17 @@ struct permon permons[NUM_OF_PERMONS] = {
 	},
 	[PM_WOLF] =
 	{
-		"wolf", "wolves", 'c', DBCLR_BROWN, 30, 6, 20, 8, -1, 10, -1, DT_PHYS, "", 10, 15, 2, 0
+		"wolf", "wolves", 'c', DBCLR_BROWN, 30, 6, 20, 8, -1, 10, -1, DT_PHYS, "", 6, 15, 2, 0
 	},
 	[PM_SNAKE] =
 	{
 		/* Saps one Body on a really good hit */
-		"snake", "snakes", 's', DBCLR_RED, 20, 6, 15, 10, -1, 3, -1, DT_PHYS, "", 10, 40, 2, PMF_STUPID
+		"snake", "snakes", 's', DBCLR_RED, 20, 6, 15, 10, -1, 3, -1, DT_PHYS, "", 9, 40, 2, PMF_STUPID
 	},
 	[PM_THUG] =
 	{
 		/* may drop a mace or leather armour */
-		"thug", "thugs", 't', DBCLR_BROWN, 30, 1, 8, 5, -1, 5, -1, DT_PHYS, "", 6, 5, 1, 0
+		"thug", "thugs", 't', DBCLR_BROWN, 30, 1, 8, 5, -1, 5, -1, DT_PHYS, "", 4, 5, 1, 0
 	},
 	[PM_GOON] =
 	{
@@ -67,11 +67,11 @@ struct permon permons[NUM_OF_PERMONS] = {
 	[PM_HUNTER] =
 	{
 		/* Has a ranged attack - arrows */
-		"hunter", "hunters", 'h', DBCLR_GREEN, 30, 9, 40, 6, 20, 6, 10, DT_PHYS, "shoots an arrow", 15, 50, 1, PMF_ARCHER
+		"hunter", "hunters", 'h', DBCLR_GREEN, 30, 9, 40, 6, 20, 6, 10, DT_PHYS, "shoots an arrow", 10, 50, 1, PMF_ARCHER
 	},
 	[PM_DUELLIST] =
 	{
-		"duellist", "duellists", 'f', DBCLR_RED, 40, 12, 60, 30, -1, 15, -1, DT_PHYS, "", 20, 130, 1, PMF_SMART
+		"duellist", "duellists", 'f', DBCLR_RED, 40, 12, 60, 30, -1, 15, -1, DT_PHYS, "", 15, 130, 1, PMF_SMART
 	},
 	[PM_WARLORD] =
 	{
@@ -84,11 +84,11 @@ struct permon permons[NUM_OF_PERMONS] = {
 	},
 	[PM_BAD_ELF] =
 	{
-		"bad elf", "bad elves", 'e', DBCLR_L_GREY, 40, 3, 15, 10, -1, 6, -1, DT_PHYS, "", 12, 15, 2, PMF_SMART
+		"bad elf", "bad elves", 'e', DBCLR_L_GREY, 40, 3, 15, 10, -1, 6, -1, DT_PHYS, "", 8, 15, 2, PMF_SMART
 	},
 	[PM_TROLL] =
 	{
-		"troll", "trolls", 'T', DBCLR_GREEN, 20, 12, 80, 15, -1, 15, -1, DT_PHYS, "", 15, 150, 1, PMF_STUPID
+		"troll", "trolls", 'T', DBCLR_GREEN, 20, 12, 80, 15, -1, 15, -1, DT_PHYS, "", 13, 150, 1, PMF_STUPID
 	},
 	[PM_GIANT] =
 	{
@@ -101,61 +101,61 @@ struct permon permons[NUM_OF_PERMONS] = {
 	[PM_WIZARD] =
 	{
 		/* Uses black magic against you; see bmagic.c for details. */
-		"wizard", "wizards", 'w', DBCLR_BLUE, 80, 12, 40, 10, 20, 10, 10, DT_ELEC, "casts", 15, 200, 1, PMF_SMART
+		"wizard", "wizards", 'w', DBCLR_BLUE, 80, 12, 40, 10, 20, 10, 10, DT_ELEC, "casts", 15, 200, 1, PMF_SMART | PMF_MAGICIAN
 	},
 	[PM_ARCHMAGE] =
 	{
 		/* Uses black magic against you; see bmagic.c for details. */
-		"archmage", "archmagi", 'w', DBCLR_L_BLUE, 80, 24, 80, 15, 30, 15, 15, DT_ELEC, "casts", 15, 1500, 1, PMF_SMART
+		"archmage", "archmagi", 'w', DBCLR_L_BLUE, 80, 24, 80, 15, 30, 15, 15, DT_ELEC, "casts", 15, 1500, 1, PMF_SMART | PMF_MAGICIAN
 	},
 	[PM_ZOMBIE] =
 	{
-		"zombie", "zombies", 'z', DBCLR_L_GREY, 25, 3, 30, 2, -1, 20, -1, DT_PHYS, "", 5, 7, 0, PMF_STUPID | PMF_UNDEAD
+		"zombie", "zombies", 'z', DBCLR_L_GREY, 25, 3, 30, 2, -1, 20, -1, DT_PHYS, "", 1, 7, 0, PMF_STUPID | PMF_UNDEAD | PMF_RESIST_COLD
 	},
 	[PM_WRAITH] =
 	{
-		"wraith", "wraiths", 'W', DBCLR_WHITE, 25, 12, 30, 25, -1, 5, -1, DT_PHYS, "", 5, 7, 0, PMF_SMART | PMF_UNDEAD
+		"wraith", "wraiths", 'W', DBCLR_WHITE, 25, 12, 30, 25, -1, 5, -1, DT_PHYS, "", 5, 7, 0, PMF_SMART | PMF_UNDEAD | PMF_RESIST_COLD
 	},
 	[PM_LICH] =
 	{
 		/* Uses black magic against you; see bmagic.c for details. */
-		"lich", "liches", 'L', DBCLR_L_GREY, 70, 15, 70, 15, 25, 15, 15, DT_NECRO, "casts", 15, 250, 1, PMF_SMART | PMF_UNDEAD
+		"lich", "liches", 'L', DBCLR_L_GREY, 70, 15, 70, 15, 25, 15, 15, DT_NECRO, "casts", 15, 250, 1, PMF_SMART | PMF_UNDEAD | PMF_RESIST_COLD | PMF_MAGICIAN
 	},
 	[PM_VAMPIRE] =
 	{
 		/* Vampires heal by hitting you. */
-		"vampire", "vampires", 'V', DBCLR_RED, 55, 18, 70, 25, -1, 15, -1, DT_PHYS, "", 22, 750, 1, PMF_SMART | PMF_UNDEAD
+		"vampire", "vampires", 'V', DBCLR_RED, 55, 18, 70, 25, -1, 15, -1, DT_PHYS, "", 22, 750, 1, PMF_SMART | PMF_UNDEAD | PMF_RESIST_COLD
 	},
 	[PM_MASTER_LICH] =
 	{
 		/* Master liches use black magic against you, more powerfully
 		 * than lesser practitioners. */
-		"master lich", "master liches", 'L', DBCLR_PURPLE, 60, 30, 150, 30, 30, 20, 30, DT_NECRO, "", 40, 3000, 1, PMF_SMART | PMF_UNDEAD
+		"master lich", "master liches", 'L', DBCLR_PURPLE, 60, 30, 150, 30, 30, 20, 30, DT_NECRO, "", 30, 3000, 1, PMF_SMART | PMF_UNDEAD | PMF_RESIST_COLD | PMF_MAGICIAN
 	},
 	[PM_DEMON] =
 	{
 		/* Demons summon more demons if you don't kill them
 		 * quickly. */
-		"demon", "demons", '&', DBCLR_RED, 60, 18, 40, 25, -1, 20, -1, DT_PHYS, "", 20, 500, 1, PMF_SMART | PMF_DEMONIC
+		"demon", "demons", '&', DBCLR_RED, 60, 18, 40, 25, -1, 20, -1, DT_PHYS, "", 15, 500, 1, PMF_SMART | PMF_DEMONIC | PMF_RESIST_FIRE
 	},
 	[PM_DEFILER] =
 	{
 		/* Defilers use black magic against you. */
-		"defiler", "defilers", '&', DBCLR_L_GREEN, 65, 27, 120, 30, 30, 20, 30, DT_FIRE, "", 40, 2000, 1, PMF_SMART | PMF_DEMONIC
+		"defiler", "defilers", '&', DBCLR_L_GREEN, 65, 27, 120, 30, 30, 20, 30, DT_FIRE, "", 25, 2000, 1, PMF_SMART | PMF_DEMONIC | PMF_RESIST_FIRE | PMF_MAGICIAN
 	},
 	[PM_CENTAUR] =
 	{
-		"centaur", "centaurs", 'C', DBCLR_BROWN, 30, 9, 40, 15, -1, 10, -1, DT_PHYS, "", 15, 50, 2, 0
+		"centaur", "centaurs", 'C', DBCLR_BROWN, 30, 9, 40, 15, -1, 10, -1, DT_PHYS, "", 10, 50, 2, 0
 	},
 	[PM_ICE_MONSTER] =
 	{
 		/* Fires ice blasts. */
-		"ice monster", "ice monsters", 'I', DBCLR_WHITE, 50, 6, 40, 10, 20, 15, 15, DT_COLD, "launches a blast of", 15, 35, 0, 0
+		"ice monster", "ice monsters", 'I', DBCLR_WHITE, 50, 6, 40, 10, 20, 15, 15, DT_COLD, "launches a blast of", 10, 35, 0, PMF_RESIST_COLD | PMF_ARCHER
 	},
 	[PM_DRAGON] =
 	{
 		/* Breathes fire. */
-		"dragon", "dragons", 'D', DBCLR_RED, 50, 15, 80, 20, 20, 20, 20, DT_FIRE, "breathes", 20, 300, 1, 0
+		"dragon", "dragons", 'D', DBCLR_RED, 50, 15, 80, 20, 20, 20, 20, DT_FIRE, "breathes", 18, 300, 1, PMF_RESIST_FIRE | PMF_ARCHER
 	},
 };
 
