@@ -30,109 +30,37 @@
 
 int pmon_resists_fire(int pm)
 {
-	switch (pm)
-	{
-	case PM_WIZARD:
-	case PM_DRAGON:
-	case PM_LICH:
-	case PM_DEMON:
-		return 1;
-	default:
-		return 0;
-	}
+	return !!(permons[pm].flags & PMF_RESIST_FIRE);
 }
 
 int pmon_resists_cold(int pm)
 {
-	switch (pm)
-	{
-	case PM_ICE_MONSTER:
-	case PM_WIZARD:
-	case PM_ZOMBIE:
-	case PM_LICH:
-	case PM_DEMON:
-	case PM_VAMPIRE:
-		return 1;
-	default:
-		return 0;
-	}
+	return !!(permons[pm].flags & PMF_RESIST_COLD);
 }
 
 int pmon_is_undead(int pm)
 {
-	switch (pm)
-	{
-	case PM_LICH:
-	case PM_ZOMBIE:
-	case PM_VAMPIRE:
-		return 1;
-	default:
-		return 0;
-	}
+	return !!(permons[pm].flags & PMF_UNDEAD);
 }
 
 int pmon_is_stupid(int pm)
 {
-	switch (pm)
-	{
-	case PM_TROLL:
-	case PM_NEWT:
-	case PM_SNAKE:
-	case PM_GIANT:
-	case PM_RAT:
-		return 1;
-	default:
-		return 0;
-	}
+	return !!(permons[pm].flags & PMF_STUPID);
 }
 
 int pmon_is_smart(int pm)
 {
-	switch (pm)
-	{
-	case PM_DUELLIST:
-	case PM_WARLORD:
-	case PM_WIZARD:
-	case PM_ARCHMAGE:
-	case PM_WRAITH:
-	case PM_LICH:
-	case PM_VAMPIRE:
-	case PM_DEMON:
-	case PM_DEFILER:
-	case PM_BAD_ELF:
-		return 1;
-	default:
-		return 0;
-	}
+	return !!(permons[pm].flags & PMF_SMART);
 }
 
 int pmon_is_magician(int pm)
 {
-	switch (pm)
-	{
-	case PM_LICH:
-	case PM_WIZARD:
-	case PM_MASTER_LICH:
-	case PM_ARCHMAGE:
-	case PM_DEFILER:
-		return 1;
-	default:
-		return 0;
-	}
+	return !!(permons[pm].flags & PMF_MAGICIAN);
 }
 
 int pmon_is_archer(int pm)
 {
-	if (pmon_is_magician(pm))
-	{
-		return 0;
-	}
-	if (permons[pm].rdam > 0)
-	{
-		return 1;
-	}
-	return 0;
+	return !!(permons[pm].flags & PMF_ARCHER);
 }
 
-
 /* pmon2.c */
